aboutsummaryrefslogtreecommitdiffstats
path: root/src/com
diff options
context:
space:
mode:
authorJoonas Lehtinen <joonas.lehtinen@itmill.com>2007-01-29 09:24:53 +0000
committerJoonas Lehtinen <joonas.lehtinen@itmill.com>2007-01-29 09:24:53 +0000
commitf736dd341c71d95b63a308bf59e48395ca81123e (patch)
treeb763117fd028adfcec7126abf48679992ba945c7 /src/com
parentca251b9f8080ec887468028cd60ea956729baf97 (diff)
downloadvaadin-framework-f736dd341c71d95b63a308bf59e48395ca81123e.tar.gz
vaadin-framework-f736dd341c71d95b63a308bf59e48395ca81123e.zip
Added PERCENTAGE width/height support
svn changeset:340/svn branch:toolkit
Diffstat (limited to 'src/com')
-rw-r--r--src/com/itmill/toolkit/ui/Table.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/com/itmill/toolkit/ui/Table.java b/src/com/itmill/toolkit/ui/Table.java
index ca423e0076..8b0ea67aa7 100644
--- a/src/com/itmill/toolkit/ui/Table.java
+++ b/src/com/itmill/toolkit/ui/Table.java
@@ -2148,23 +2148,23 @@ public class Table extends Select implements Action.Container,
}
/** Set height units.
* Table supports only Sizeable.UNITS_PIXELS and Sizeable.UNITS_ROWS. Setting to any other throws
* IllegalArgumentException.
* @see com.itmill.toolkit.terminal.Sizeable#setHeightUnits(int)
*/
public void setHeightUnits(int units) {
- if (units != Sizeable.UNITS_PIXELS && units != Sizeable.UNITS_ROWS)
+ if (units != Sizeable.UNITS_PIXELS && units != Sizeable.UNITS_ROWS && units != Sizeable.UNITS_PERCENTAGE)
throw new IllegalArgumentException();
this.heightUnit = units;
}
/** Set width units.
* Tabel supports only Sizeable.UNITS_PIXELS. Setting to any other throws
* IllegalArgumentException.
* @see com.itmill.toolkit.terminal.Sizeable#setWidthUnits(int)
*/
public void setWidthUnits(int units) {
- if (units != Sizeable.UNITS_PIXELS)
+ if (units != Sizeable.UNITS_PIXELS && units != Sizeable.UNITS_PERCENTAGE)
throw new IllegalArgumentException();
this.heightUnit = units;
}
@@ -2148,23 +2148,23 @@ public class Table extends Select implements Action.Container,
}
/** Set height units.
- * Table supports only Sizeable.UNITS_PIXELS and Sizeable.UNITS_ROWS. Setting to any other throws
+ * Table supports only Sizeable.UNITS_PIXELS, Sizeable.UNITS_PERCENTAGE and Sizeable.UNITS_ROWS. Setting to any other throws
* IllegalArgumentException.
* @see com.itmill.toolkit.terminal.Sizeable#setHeightUnits(int)
@@ -2148,23 +2148,23 @@ public class Table extends Select implements Action.Container,
}
/** Set width units.
- * Tabel supports only Sizeable.UNITS_PIXELS. Setting to any other throws
+ * Tabel supports only Sizeable.UNITS_PIXELS and Sizeable.UNITS_PERCENTAGE. Setting to any other throws
* IllegalArgumentException.
* @see com.itmill.toolkit.terminal.Sizeable#setWidthUnits(int)